@@ -430,17 +430,7 @@ async fn handle_connection_events(
                 };
 
                 let span = {
-                    let mut core = dispatcher.core.write().await;
-
-                    if !core.add_to_filter(&wire_msg).await {
-                        trace!(
-                            "not handling message {:?} from {}, already handled",
-                            wire_msg.msg_id(),
-                            sender,
-                        );
-                        continue;
-                    }
-
+                    let core = dispatcher.core.read().await;
                     trace_span!("handle_message", name = %core.node().name(), %sender)
                 };
                 let _span_guard = span.enter();
